[java-oidc-common] 11/35: Change default JWT security params creation on outbound ctx

Phil Smart philip.smart at jisc.ac.uk
Tue Sep 20 14:19:11 UTC 2022


This is an automated email from the git hooks/post-receive script.

philsmart pushed a commit to branch dev/JCOMOIDC-41
in repository java-oidc-common.

View the commit online:
http://git.shibboleth.net/view/?p=java-oidc-common.git;a=commit;h=526a4cbcfef42e525bc49b45974b9d2dfc38e7d0

commit 526a4cbcfef42e525bc49b45974b9d2dfc38e7d0
Author: Phil Smart <philip.smart at jisc.ac.uk>
AuthorDate: Fri Jul 1 14:41:20 2022 +0100

    Change default JWT security params creation on outbound ctx
    
     - makes more sense to be on outbound when signing and inbound on
    validation
---
 .../oidc/security/impl/PopulateJWTSignatureSigningParameters.java    | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/oidc-common-crypto-impl/src/main/java/net/shibboleth/oidc/security/impl/PopulateJWTSignatureSigningParameters.java b/oidc-common-crypto-impl/src/main/java/net/shibboleth/oidc/security/impl/PopulateJWTSignatureSigningParameters.java
index 0e94ba5..c74f997 100644
--- a/oidc-common-crypto-impl/src/main/java/net/shibboleth/oidc/security/impl/PopulateJWTSignatureSigningParameters.java
+++ b/oidc-common-crypto-impl/src/main/java/net/shibboleth/oidc/security/impl/PopulateJWTSignatureSigningParameters.java
@@ -14,6 +14,7 @@ import org.opensaml.profile.action.AbstractHandlerDelegatingProfileAction;
 import org.opensaml.profile.action.EventIds;
 import org.opensaml.profile.context.ProfileRequestContext;
 import org.opensaml.profile.context.navigate.InboundMessageContextLookup;
+import org.opensaml.profile.context.navigate.OutboundMessageContextLookup;
 import org.opensaml.xmlsec.SecurityConfigurationSupport;
 import org.opensaml.xmlsec.SignatureSigningConfiguration;
 import org.opensaml.xmlsec.SignatureSigningParametersResolver;
@@ -70,10 +71,10 @@ public class PopulateJWTSignatureSigningParameters
         
         setErrorEvent(EventIds.INVALID_SEC_CFG);
         
         // Create context by default.
         securityParametersContextLookupStrategy =
                 new ChildContextLookup<>(JWTSecurityParametersContext.class, true).compose(
-                        new InboundMessageContextLookup());
+                        new OutboundMessageContextLookup());
         
         noResultIsError = false;
     }
@@ -70,10 +71,10 @@ public class PopulateJWTSignatureSigningParameters
         setErrorEvent(EventIds.INVALID_SEC_CFG);
         
-        // Create context by default.
+        // Create context by default on the outbound context
         securityParametersContextLookupStrategy =
                 new ChildContextLookup<>(JWTSecurityParametersContext.class, true).compose(

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list